% TRAPEZOIDAL  Perfil de velocidad trapezoidal
%    PERFIL=TRAPEZOIDAL(U) devuelve un vector 1x2 que contiene la velocidad 
%    y la aceleracin de un perfil de velocidad trapezoidal en un determinado 
%    instante de tiempo. PERFIL(1) contiene la velocidad y PERFIL(2) la 
%    aceleracin. U(1) representa el instante de tiempo actual(seg). U(2) es 
%    la velocidad mxima. U(3) es el tiempo de aceleracin(seg). U(4) es el
%    tiempo de velocidad constante(seg). U(5) es el tiempo de deceleracin(seg).

function perfil=trapezoidal(u)

t      = u(1);	% Instante de tiempo actual
velmax = u(2);  % Velocidad mxima
tacel  = u(3);	% Tiempo de aceleracin
tconst = u(4);	% Tiempo de velocidad constante
tdecel = u(5);	% Tiempo de deceleracin

% Se calcula la velocidad y la aceleracin
if t <= tacel
   % Intervalo de aceleracin
   acel = velmax/tacel;
   vel  = acel*t;
else
    if t < (tacel+tconst)
	% Intervalo de velocidad constante
        vel  = velmax;
        acel = 0;
    else
        if t>(tacel+tconst+tdecel)
	   % Velocidad y aceleracin nula
           vel  = 0;
           acel = 0;
        else
	   % Intervalo de deceleracin
           acel = -velmax/tdecel;
           vel  = velmax+acel*(t-tacel-tconst);
        end         
   end
end

% Se devuelve la velocidad y la aceleracin
perfil = [vel acel];
